from os.path import abspath, dirname, join

config_path = abspath(dirname(__file__))
filters_path = join(config_path, 'filters')
